@@ -17,3 +17,15 @@ test_that("Contourmap, test ind", {
   expect_equal(res1$F,res2$F,tolerance=1e-7)
   expect_equal(res2$F,res3$F,tolerance=1e-7)
 })
+
+
+test_that("Contourmap, P measures", {
+  data <- integration.testdata1()
+
+  res1 = contourmap(data$mu, data$Q, n.levels=4,
+                    seed=data$seed, alpha=0.1,max.threads=1,
+                    compute = list(F = FALSE, measures = c("P2","P1")))
+
+  expect_equal(res1$P1,0.9217417,tolerance=1e-3)
+  expect_equal(res1$P2,0.405841,tolerance=1e-3)
+})
