@@ -1,7 +1,7 @@
 context("Excursions.inla")
 
 test_that("excursions.inla, test ind", {
-  if(require("INLA", quietly=TRUE)){
+  if(require.nowarnings("INLA")){
   data <- testdata.inla()
   ind1 = c(1,2,3,4)
   ind2 = c(4,3,2,1)
